diff -ruN EMBOSS-2.9.0.orig/ajax/ajhist.h EMBOSS-2.9.0/ajax/ajhist.h
--- EMBOSS-2.9.0.orig/ajax/ajhist.h	2004-07-31 22:20:23.596527176 +0100
+++ EMBOSS-2.9.0/ajax/ajhist.h	2004-07-31 22:20:39.340133784 +0100
@@ -125,10 +125,10 @@
 void    ajHistSetMultiYTitleC (AjPHist hist, ajint index, const char *title);
 void    ajHistSetPattern (AjPHist hist, ajint index, ajint style);
 void    ajHistSetPtrToData (AjPHist hist, ajint index, PLFLT *data);
-void    ajHistSetTitleC (AjPHist hist, const char* string);
-void    ajHistSetXAxisC (AjPHist hist, const char* string);
-void    ajHistSetYAxisLeftC (AjPHist hist,const  char* string);
-void    ajHistSetYAxisRightC (AjPHist hist, const char* string);
+void    ajHistSetTitleC (AjPHist hist, const char* strng);
+void    ajHistSetXAxisC (AjPHist hist, const char* strng);
+void    ajHistSetYAxisLeftC (AjPHist hist,const  char* strng);
+void    ajHistSetYAxisRightC (AjPHist hist, const char* strng);
 
 #endif /* ajhist_h */
 
diff -ruN EMBOSS-2.9.0.orig/ajax/ajstr.h EMBOSS-2.9.0/ajax/ajstr.h
--- EMBOSS-2.9.0.orig/ajax/ajstr.h	2004-07-31 22:20:23.614524440 +0100
+++ EMBOSS-2.9.0/ajax/ajstr.h	2004-07-31 22:22:05.130091728 +0100
@@ -412,7 +412,7 @@
 AjBool     ajStrReplaceS( AjPStr* pthis, ajint begin, const AjPStr overwrite);
 ajint      ajStrRef(const AjPStr thys);
 #define    MAJSTRREF(str) str->Use
-void       ajStrRemoveCharsC(AjPStr* this, const char *string);
+void       ajStrRemoveCharsC(AjPStr* pthis, const char *strng);
 void       ajStrRemoveHtml(AjPStr* pthis);
 void       ajStrRemoveNewline(AjPStr* pthis);
 AjBool     ajStrRev (AjPStr* pthis);
diff -ruN EMBOSS-2.9.0.orig/nucleus/embest.h EMBOSS-2.9.0/nucleus/embest.h
--- EMBOSS-2.9.0.orig/nucleus/embest.h	2004-07-31 22:20:23.847489024 +0100
+++ EMBOSS-2.9.0/nucleus/embest.h	2004-07-31 22:20:39.348132568 +0100
@@ -185,7 +185,7 @@
      /* similar to file_time() execpt that a pointer to the date (in
 	English) */
 
-ajint legal_string( char *string, char **strings, ajint size, ajint *value );
+ajint legal_string( char *strng, char **strings, ajint size, ajint *value );
 
 /* checks if string is a member os strings, and sets value to the
 index in the array strings returns 1 on success and 0 on failure */
@@ -223,9 +223,9 @@
 
 ajint matches_extension( char *name, char *ext );
 ajint matches_suffix( char *name, char *suffix );
-ajint hash_name( char *string );
+ajint hash_name( char *strng );
 char *has_extension( char *name );
-ajint uncomment( char *string );
+ajint uncomment( char *strng );
 void indent( void );
 
 
diff -ruN EMBOSS-2.9.0.orig/nucleus/embpat.h EMBOSS-2.9.0/nucleus/embpat.h
--- EMBOSS-2.9.0.orig/nucleus/embpat.h	2004-07-31 22:20:23.849488720 +0100
+++ EMBOSS-2.9.0/nucleus/embpat.h	2004-07-31 22:20:39.359130896 +0100
@@ -162,7 +162,7 @@
 				 const ajint *next, ajint start);
 
 void            embPatMatchDel (EmbPPatMatch* pthis);
-EmbPPatMatch    embPatMatchFind  (const AjPStr regexp, const AjPStr string);
+EmbPPatMatch    embPatMatchFind  (const AjPStr regexp, const AjPStr strng);
 EmbPPatMatch    embPatMatchFindC (const AjPStr regexp, const char *sptr);
 ajint           embPatMatchGetEnd (const EmbPPatMatch data, ajint index);
 ajint           embPatMatchGetLen (const EmbPPatMatch data, ajint index);
diff -ruN EMBOSS-2.9.0.orig/plplot/plplotP.h EMBOSS-2.9.0/plplot/plplotP.h
--- EMBOSS-2.9.0.orig/plplot/plplotP.h	2004-07-31 22:20:23.835490848 +0100
+++ EMBOSS-2.9.0/plplot/plplotP.h	2004-07-31 22:20:39.360130744 +0100
@@ -335,7 +335,7 @@
 /* (refx,refy). */
 
 void
-plstr(PLINT base, PLFLT *xform, PLINT refx, PLINT refy, const char *string);
+plstr(PLINT base, PLFLT *xform, PLINT refx, PLINT refy, const char *strng);
 
 /* Draws a tick parallel to x. */
 
@@ -466,7 +466,7 @@
 /* Computes the length of a string in mm, including escape sequences. */
 
 PLFLT
-plstrl(const char *string);
+plstrl(const char *strng);
 
 /* Similar to strpos, but searches for occurence of string str2. */
 
diff -ruN EMBOSS-2.9.0.orig/plplot/plsym.c EMBOSS-2.9.0/plplot/plsym.c
--- EMBOSS-2.9.0.orig/plplot/plsym.c	2004-07-31 22:20:23.843489632 +0100
+++ EMBOSS-2.9.0/plplot/plsym.c	2004-07-31 22:20:39.361130592 +0100
@@ -668,7 +668,7 @@
 \*--------------------------------------------------------------------------*/
 
 PLFLT
-plstrl(const char *string)
+plstrl(const char *strng)
 {
     short int *symbol;
     signed char *xygrid;
@@ -678,7 +678,7 @@
     plgchr(&def, &ht);
     dscale = 0.05 * ht;
     scale = dscale;
-    pldeco(&symbol, &length, string);
+    pldeco(&symbol, &length, strng);
 
     for (i = 0; i < length; i++) {
 	ch = symbol[i];

diff -ruN EMBOSS-2.9.0.orig/ajax/ajhist.c EMBOSS-2.9.0/ajax/ajhist.c
--- EMBOSS-2.9.0.orig/ajax/ajhist.c	2004-07-31 22:20:23.596527176 +0100
+++ EMBOSS-2.9.0/ajax/ajhist.c	2004-07-31 22:20:39.310138344 +0100
@@ -716,14 +716,14 @@
 ** Copy Title for the histogram.
 **
 ** @param [u] hist [AjPHist] histogram to set string in.
 ** @param [r] string [const char*] text to be copied.
 ** @return [void]
 ** @@
 ******************************************************************************/
 
-void ajHistSetTitleC(AjPHist hist, const char* string)
+void ajHistSetTitleC(AjPHist hist, const char* strng)
 {
-    ajStrAssC(&hist->title,string);
+    ajStrAssC(&hist->title,strng);
 
     return;
 }
@@ -736,14 +736,14 @@
 ** Store X axis label for the histogram
 **
 ** @param [u] hist [AjPHist] histogram to set string in.
 ** @param [r] string [const char*] text to be copied.
 ** @return [void]
 ** @@
 ******************************************************************************/
 
-void ajHistSetXAxisC(AjPHist hist, const char* string)
+void ajHistSetXAxisC(AjPHist hist, const char* strng)
 {
-    ajStrAssC(&hist->xaxis,string);
+    ajStrAssC(&hist->xaxis,strng);
 
     return;
 }
@@ -756,14 +756,14 @@
 ** Store Y Axis Left Label for the histogram
 **
 ** @param [u] hist [AjPHist] histogram to set string in.
 ** @param [r] string [const char*] text to be copied.
 ** @return [void]
 ** @@
 ******************************************************************************/
 
-void ajHistSetYAxisLeftC(AjPHist hist, const char* string)
+void ajHistSetYAxisLeftC(AjPHist hist, const char* strng)
 {
-    ajStrAssC(&hist->yaxisleft,string);
+    ajStrAssC(&hist->yaxisleft,strng);
 
     return;
 }
@@ -776,14 +776,14 @@
 ** Store Y Axis Right Label for the histogram
 **
 ** @param [u] hist [AjPHist] histogram to set string in.
 ** @param [r] string [const char*] text to be copied.
 ** @return [void]
 ** @@
 ******************************************************************************/
 
-void ajHistSetYAxisRightC(AjPHist hist, const char* string)
+void ajHistSetYAxisRightC(AjPHist hist, const char* strng)
 {
-    ajStrAssC(&hist->yaxisright,string);
+    ajStrAssC(&hist->yaxisright,strng);
 
     return;
 }
@@ -716,14 +716,14 @@
 **
 ** @param [u] hist [AjPHist] histogram to set string in.
-** @param [r] string [const char*] text to be copied.
+** @param [r] strng [const char*] text to be copied.
 ** @return [void]
 ** @@
@@ -736,14 +736,14 @@
 **
 ** @param [u] hist [AjPHist] histogram to set string in.
-** @param [r] string [const char*] text to be copied.
+** @param [r] strng [const char*] text to be copied.
 ** @return [void]
 ** @@
@@ -756,14 +756,14 @@
 **
 ** @param [u] hist [AjPHist] histogram to set string in.
-** @param [r] string [const char*] text to be copied.
+** @param [r] strng [const char*] text to be copied.
 ** @return [void]
 ** @@
@@ -776,14 +776,14 @@
 **
 ** @param [u] hist [AjPHist] histogram to set string in.
-** @param [r] string [const char*] text to be copied.
+** @param [r] strng [const char*] text to be copied.
 ** @return [void]
 ** @@
diff -ruN EMBOSS-2.9.0.orig/ajax/ajstr.c EMBOSS-2.9.0/ajax/ajstr.c
--- EMBOSS-2.9.0.orig/ajax/ajstr.c	2004-07-31 22:20:23.614524440 +0100
+++ EMBOSS-2.9.0/ajax/ajstr.c	2004-07-31 22:20:39.345133024 +0100
@@ -7655,12 +7655,12 @@
 ** Removes all of a given set of characters from a string
 **
 ** @param [w] pthis [AjPStr*] String
 ** @param [r] string [const char*] characters to remove
 ** @return [void]
 ** @@
 ******************************************************************************/
 
-void ajStrRemoveCharsC(AjPStr* pthis, const char *string)
+void ajStrRemoveCharsC(AjPStr* pthis, const char *strng)
 {
     char *p = NULL;
     char *q = NULL;
@@ -7675,7 +7675,7 @@
     p = thys->Ptr;
     q = p;
 
-    while((r=strpbrk(p,string)))
+    while((r=strpbrk(p,strng)))
     {
 	while(p!=r)
 	    *(q++) = *(p++);
@@ -7655,12 +7655,12 @@
 **
 ** @param [w] pthis [AjPStr*] String
-** @param [r] string [const char*] characters to remove
+** @param [r] strng [const char*] characters to remove
 ** @return [void]
 ** @@
diff -ruN EMBOSS-2.9.0.orig/nucleus/embpat.c EMBOSS-2.9.0/nucleus/embpat.c
--- EMBOSS-2.9.0.orig/nucleus/embpat.c	2004-07-31 22:20:23.849488720 +0100
+++ EMBOSS-2.9.0/nucleus/embpat.c	2004-07-31 22:20:39.358131048 +0100
@@ -215,15 +215,15 @@
 ** Find all the regular expression matches of reg in the string string.
 **
 ** @param [r] regexp [const AjPStr] Regular expression string.
 ** @param [r] string [const AjPStr] String to be searched.
 **
 ** @return [EmbPPatMatch] Results of the pattern matching.
 **
 ******************************************************************************/
 
-EmbPPatMatch embPatMatchFind(const AjPStr regexp, const AjPStr string)
+EmbPPatMatch embPatMatchFind(const AjPStr regexp, const AjPStr strng)
 {
-    return embPatMatchFindC(regexp, ajStrStr(string));
+    return embPatMatchFindC(regexp, ajStrStr(strng));
 }
 
 
@@ -215,15 +215,15 @@
 **
 ** @param [r] regexp [const AjPStr] Regular expression string.
-** @param [r] string [const AjPStr] String to be searched.
+** @param [r] strng [const AjPStr] String to be searched.
 **
 ** @return [EmbPPatMatch] Results of the pattern matching.